@@ -12,7 +12,7 @@ use File::Spec::Functions qw(catfile catdir splitdir);
 use vars qw($VERSION @Pagers $Bindir $Pod2man
   $Temp_Files_Created $Temp_File_Lifetime
 );
-$VERSION = '3.15_14';
+$VERSION = '3.19_01';
 
 #..........................................................................
 
@@ -31,6 +31,18 @@ use Pod::Perldoc::GetOptsOO; # uses the DEBUG.
 use Carp qw(croak carp);
 
 # these are also in BaseTo, which I don't want to inherit
+sub debugging {
+	my $self = shift;
+
+    ( defined(&Pod::Perldoc::DEBUG) and &Pod::Perldoc::DEBUG() )
+	}
+
+sub debug {
+	my( $self, @messages ) = @_;
+	return unless $self->debugging;
+	print STDERR map { "DEBUG : $_" } @messages;
+	}
+
 sub warn {
   my( $self, @messages ) = @_;
 
@@ -253,7 +265,7 @@ sub usage {
   # Erase evidence of previous errors (if any), so exit status is simple.
   $! = 0;
 
-  $self->die( <<EOF );
+  CORE::die( <<EOF );
 perldoc [options] PageName|ModuleName|ProgramName|URL...
 perldoc [options] -f BuiltinFunction
 perldoc [options] -q FAQRegex
@@ -317,6 +329,7 @@ sub program_name {
 
   my $basename = basename( $0 );
 
+  $self->debug( "\$0 is [$0]\nbasename is [$basename]\n" );
   # possible name forms
   #   perldoc
   #   perldoc-v5.14
@@ -327,15 +340,15 @@ sub program_name {
   my( $untainted ) = $basename =~ m/(
     \A
     perl
-      (?:
-      doc | func | faq | help | op | toc | var # Camel 3
-      )
-    (?: -? v? \d+ \. \d+ (?:\. \d+)? ) # possible version
+      (?: doc | func | faq | help | op | toc | var # Camel 3
+      ) 
+    (?: -? v? \d+ \. \d+ (?:\. \d+)? )? # possible version
     (?: \. (?: bat | exe | com ) )?    # possible extension
     \z
     )
     /x;
 
+  $self->debug($untainted);
   return $untainted if $untainted;
   }
 
@@ -343,9 +356,10 @@ sub program_name {
 You called the perldoc command with a name that I didn't recognize.
 This might mean that someone is tricking you into running a
 program you don't intend to use, but it also might mean that you
-created your own link to perldoc.
+created your own link to perldoc. I think your program name is
+[$basename].
 
-I'll allow this if the filename looks only has [a-zA-Z0-9._-].
+I'll allow this if the filename only has [a-zA-Z0-9._-].
 HERE
 
   {
@@ -353,6 +367,7 @@ HERE
     \A [a-zA-Z0-9._-]+ \z
     )/x;
 
+  $self->debug($untainted);
   return $untainted if $untainted;
   }
 
@@ -373,7 +388,7 @@ sub usage_brief {
   my $self = shift;
   my $program_name = $self->program_name;
 
-  $self->die( <<"EOUSAGE" );
+  CORE::die( <<"EOUSAGE" );
 Usage: $program_name [-hVriDtumFXlT] [-n nroffer_program]
     [-d output_filename] [-o output_format] [-M FormatterModule]
     [-w formatter_option:option_value] [-L translation_code]
@@ -455,7 +470,7 @@ sub init_formatter_class_list {
 
   $self->opt_M_with('Pod::Perldoc::ToPod');   # the always-there fallthru
   $self->opt_o_with('text');
-  $self->opt_o_with('man') unless $self->is_mswin32 || $self->is_dos
+  $self->opt_o_with('term') unless $self->is_mswin32 || $self->is_dos
        || !($ENV{TERM} && (
               ($ENV{TERM} || '') !~ /dumb|emacs|none|unknown/i
            ));
@@ -520,7 +535,7 @@ sub process {
     my @found = $self->grand_search_init(\@pages);
     exit ($self->is_vms ? 98962 : 1) unless @found;
 
-    if ($self->opt_l) {
+    if ($self->opt_l and not $self->opt_q ) {
         DEBUG and print "We're in -l mode, so byebye after this:\n";
         print join("\n", @found), "\n";
         return;
@@ -783,7 +798,7 @@ sub options_sanity {
     if( $self->opt_f or $self->opt_q ) {
     $self->usage("Only one of -f -or -q") if $self->opt_f and $self->opt_q;
     $self->warn(
-        "Perldoc is only really meant for reading one word at a time.\n",
+        "Perldoc is meant for reading one file at a time.\n",
         "So these parameters are being ignored: ",
         join(' ', @{$self->{'args'}}),
         "\n" )
@@ -1004,7 +1019,7 @@ sub search_perlvar {
     my $opt = $self->opt_v;
 
     if ( $opt !~ /^ (?: [\@\%\$]\S+ | [A-Z]\w* ) $/x ) {
-        $self->die( "'$opt' does not look like a Perl variable\n" );
+        CORE::die( "'$opt' does not look like a Perl variable\n" );
     }
 
     DEBUG > 2 and print "Search: @$found_things\n";
@@ -1063,7 +1078,7 @@ sub search_perlvar {
     }
     @$pod = () unless $found;
     if (!@$pod) {
-        $self->die( "No documentation for perl variable '$opt' found\n" );
+        CORE::die( "No documentation for perl variable '$opt' found\n" );
     }
     close PVAR                or $self->die( "Can't open $perlvar: $!" );
 
@@ -1200,8 +1215,8 @@ sub search_perlfunc {
     }
 
     if (!@$pod) {
-        $self->die( sprintf
-          "No documentation for perl function `%s' found\n",
+        CORE::die( sprintf
+          "No documentation for perl function '%s' found\n",
           $self->opt_f )
         ;
     }
@@ -1245,9 +1260,12 @@ EOD
         }
         close(INFAQ);
     }
-    $self->die("No documentation for perl FAQ keyword `$search_key' found\n")
+    CORE::die("No documentation for perl FAQ keyword '$search_key' found\n")
      unless @$pod;
 
+    if ( $self->opt_l ) {
+        CORE::die((join "\n", keys %found_in) . "\n");
+    }
     return;
 }
 
@@ -1405,7 +1423,7 @@ sub minus_f_nocase {   # i.e., do like -f, but without regard to case
 
      if(!$self->opt_i
         or $self->is_vms or $self->is_mswin32
-        or $self->Is_dos or $self->is_os2
+        or $self->is_dos or $self->is_os2
      ) {
         # On a case-forgiving file system, or if case is important,
     #  that is it, all we can do.
@@ -1486,7 +1504,7 @@ sub pagers_guessing {
           unshift @pagers, 'less', 'cmd /c more <';
         }
         push @pagers, qw( more less pg view cat );
-        unshift @pagers, "$ENV{PAGER}<"  if $ENV{PAGER};
+        unshift @pagers, "$ENV{PAGER} <"  if $ENV{PAGER};
     }
 
     if ($self->is_cygwin) {
@@ -1496,7 +1514,7 @@ sub pagers_guessing {
        }
     }
 
-    unshift @pagers, $ENV{PERLDOC_PAGER} if $ENV{PERLDOC_PAGER};
+    unshift @pagers, "$ENV{PERLDOC_PAGER} <" if $ENV{PERLDOC_PAGER};
 
     return;
 }
@@ -1932,9 +1950,10 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Current maintainer: brian d foy C<< <bdfoy@cpan.org> >>
+Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
 
 Past contributions from:
+brian d foy C<< <bdfoy@cpan.org> >>
 Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
 Sean M. Burke C<< <sburke@cpan.org> >>
 
