@@ -1,10 +1,9 @@
-require 5;
 package Pod::Perldoc::ToTk;
 use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '3.15_14';
+$VERSION = '3.19_01';
 
 use parent qw(Pod::Perldoc::BaseTo);
 
@@ -142,9 +141,10 @@ L<Tk::Pod>, L<Pod::Perldoc>
 
 =head1 AUTHOR
 
-Current maintainer: brian d foy C<< <bdfoy@cpan.org> >>
+Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
 
 Past contributions from:
+brian d foy C<< <bdfoy@cpan.org> >>
 Adriano R. Ferreira C<< <ferreira@cpan.org> >>;
 Sean M. Burke C<< <sburke@cpan.org> >>;
 significant portions copied from
