@@ -1,4 +1,3 @@
-require 5;
 package Pod::Perldoc::ToXml;
 use strict;
 use warnings;
@@ -7,7 +6,7 @@ use vars qw($VERSION);
 use parent qw( Pod::Simple::XMLOutStream );
 
 use vars qw($VERSION);
-$VERSION = '3.15_14';
+$VERSION = '3.19_01';
 
 sub is_pageable        { 0 }
 sub write_with_binmode { 0 }
@@ -53,9 +52,10 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Current maintainer: brian d foy C<< <bdfoy@cpan.org> >>
+Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
 
 Past contributions from:
+brian d foy C<< <bdfoy@cpan.org> >>
 Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
 Sean M. Burke C<< <sburke@cpan.org> >>
 
